==> kubernetes-model-0.1.4-sources.jar: annotations/io/fabric8/kubernetes/api/model/ServiceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ServiceFluent<T extends ServiceFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     Service.ApiVersion apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<ServiceSpec, ?> spec;     VisitableBuilder<ServiceStatus, ?> status;     Map<String, Object> additionalProperties = new HashMap();

    public Service.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( Service.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public ServiceSpec getSpec(){
    return this.spec!=null?this.spec.build():null;
    }
    public T withSpec( ServiceSpec spec){
    if (spec!=null){ this.spec= new ServiceSpecBuilder(spec); _visitables.add(this.spec);} return (T) this;
    }
    public SpecNested<T> withNewSpec(){
    return new SpecNested<T>();
    }
    public SpecNested<T> withNewSpecLike( ServiceSpec item){
    return new SpecNested<T>(item);
    }
    public SpecNested<T> editSpec(){
    return withNewSpecLike(getSpec());
    }
    public ServiceStatus getStatus(){
    return this.status!=null?this.status.build():null;
    }
    public T withStatus( ServiceStatus status){
    if (status!=null){ this.status= new ServiceStatusBuilder(status); _visitables.add(this.status);} return (T) this;
    }
    public StatusNested<T> withNewStatus(){
    return new StatusNested<T>();
    }
    public StatusNested<T> withNewStatusLike( ServiceStatus item){
    return new StatusNested<T>(item);
    }
    public StatusNested<T> editStatus(){
    return withNewStatusLike(getStatus());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N and(){
            return (N) ServiceFluent.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class SpecNested<N> extends ServiceSpecFluent<SpecNested<N>> implements Nested<N>{

        private final ServiceSpecBuilder builder;
    
             SpecNested ( ServiceSpec item){
        this.builder = new ServiceSpecBuilder(this, item);
        }
             SpecNested (){
        this.builder = new ServiceSpecBuilder(this);
        }
    
            public N endSpec(){
            return and();
        }
            public N and(){
            return (N) ServiceFluent.this.withSpec(builder.build());
        }
    
}
    public class StatusNested<N> extends ServiceStatusFluent<StatusNested<N>> implements Nested<N>{

        private final ServiceStatusBuilder builder;
    
             StatusNested (){
        this.builder = new ServiceStatusBuilder(this);
        }
             StatusNested ( ServiceStatus item){
        this.builder = new ServiceStatusBuilder(this, item);
        }
    
            public N and(){
            return (N) ServiceFluent.this.withStatus(builder.build());
        }
            public N endStatus(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.19-sources.jar: annotations/io/fabric8/kubernetes/api/model/ServiceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class ServiceFluent<T extends ServiceFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     Service.ApiVersion apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<ServiceSpec, ?> spec;     VisitableBuilder<ServiceStatus, ?> status;     Map<String, Object> additionalProperties = new HashMap();

    public Service.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( Service.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public ServiceSpec getSpec(){
    return this.spec!=null?this.spec.build():null;
    }
    public T withSpec( ServiceSpec spec){
    if (spec!=null){ this.spec= new ServiceSpecBuilder(spec); _visitables.add(this.spec);} return (T) this;
    }
    public SpecNested<T> withNewSpec(){
    return new SpecNested<T>();
    }
    public SpecNested<T> withNewSpecLike( ServiceSpec item){
    return new SpecNested<T>(item);
    }
    public SpecNested<T> editSpec(){
    return withNewSpecLike(getSpec());
    }
    public ServiceStatus getStatus(){
    return this.status!=null?this.status.build():null;
    }
    public T withStatus( ServiceStatus status){
    if (status!=null){ this.status= new ServiceStatusBuilder(status); _visitables.add(this.status);} return (T) this;
    }
    public StatusNested<T> withNewStatus(){
    return new StatusNested<T>();
    }
    public StatusNested<T> withNewStatusLike( ServiceStatus item){
    return new StatusNested<T>(item);
    }
    public StatusNested<T> editStatus(){
    return withNewStatusLike(getStatus());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ServiceFluent that = (ServiceFluent) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
if (status != null ? !status.equals(that.status) :that.status != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
    
            public N and(){
            return (N) ServiceFluent.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class SpecNested<N> extends ServiceSpecFluent<SpecNested<N>> implements Nested<N>{

        private final ServiceSpecBuilder builder;
    
             SpecNested ( ServiceSpec item){
        this.builder = new ServiceSpecBuilder(this, item);
        }
             SpecNested (){
        this.builder = new ServiceSpecBuilder(this);
        }
    
            public N endSpec(){
            return and();
        }
            public N and(){
            return (N) ServiceFluent.this.withSpec(builder.build());
        }
    
}
    public class StatusNested<N> extends ServiceStatusFluent<StatusNested<N>> implements Nested<N>{

        private final ServiceStatusBuilder builder;
    
             StatusNested (){
        this.builder = new ServiceStatusBuilder(this);
        }
             StatusNested ( ServiceStatus item){
        this.builder = new ServiceStatusBuilder(this, item);
        }
    
            public N and(){
            return (N) ServiceFluent.this.withStatus(builder.build());
        }
            public N endStatus(){
            return and();
        }
    
}


}
